@@ -1,3 +1,5 @@
+from types import GeneratorType
+
 
 class RepeatableIterator(object):
     """
@@ -7,12 +9,22 @@ class RepeatableIterator(object):
     
     def __init__(self, generator):
         self.generator = generator
+        self.__val = None
 
     def __iter__(self):
         return self.generator()
 
+    def __bool__(self):
+        try:
+            self.__iter__().next()
+            return True
+        except StopIteration:
+            return False
+
+    __nonzero__ = __bool__
+
     @classmethod
     def to_jvalue(cls, obj):
         if isinstance(obj, cls):
             return list(obj)
-        raise TypeError(repr(o) + 'is not JSON serializable')
+        raise TypeError(repr(obj) + 'is not JSON serializable')
\ No newline at end of file
